[gimp] libgimp*: various doc fixes
- From: Michael Natterer <mitch src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] libgimp*: various doc fixes
- Date: Sat, 10 Aug 2019 10:33:32 +0000 (UTC)
commit e6d662e3525a59bd5b877de38f4f7e81c51aadd6
Author: Michael Natterer <mitch gimp org>
Date: Sat Aug 10 12:32:25 2019 +0200
libgimp*: various doc fixes
libgimp/gimpprocedure.c | 4 ++--
libgimpbase/gimpparamspecs.c | 8 ++++----
libgimpbase/gimpparasite.c | 28 +---------------------------
libgimpbase/gimpparasite.h | 2 ++
libgimpbase/gimputils.c | 2 +-
libgimpcolor/gimprgb.c | 2 --
libgimpcolor/gimprgb.h | 1 +
7 files changed, 11 insertions(+), 36 deletions(-)
---
diff --git a/libgimp/gimpprocedure.c b/libgimp/gimpprocedure.c
index dd062d8ce9..6336269eae 100644
--- a/libgimp/gimpprocedure.c
+++ b/libgimp/gimpprocedure.c
@@ -326,7 +326,7 @@ gimp_procedure_real_run (GimpProcedure *procedure,
*
* Since: 3.0
**/
-GimpProcedure *
+GimpProcedure *
gimp_procedure_new (GimpPlugIn *plug_in,
const gchar *name,
GimpPDBProcType proc_type,
@@ -658,7 +658,7 @@ gimp_procedure_set_attribution (GimpProcedure *procedure,
}
/**
- * gimp_procedure_get_author:
+ * gimp_procedure_get_authors:
* @procedure: A #GimpProcedure.
*
* Returns: The procedure's authors given in
diff --git a/libgimpbase/gimpparasite.c b/libgimpbase/gimpparasite.c
index 2341237120..bf9f219cee 100644
--- a/libgimpbase/gimpparasite.c
+++ b/libgimpbase/gimpparasite.c
@@ -75,8 +75,6 @@ gimp_parasite_get_type (void)
#define GIMP_PARAM_SPEC_PARASITE(pspec) (G_TYPE_CHECK_INSTANCE_CAST ((pspec), GIMP_TYPE_PARAM_PARASITE,
GimpParamSpecParasite))
-typedef struct _GimpParamSpecParasite GimpParamSpecParasite;
-
struct _GimpParamSpecParasite
{
GParamSpecBoxed parent_instance;
@@ -184,7 +182,7 @@ gimp_param_parasite_values_cmp (GParamSpec *pspec,
*
* Returns: (transfer full): The newly created #GimpParamSpecParasite.
*
- * Since: 2.3.8
+ * Since: 2.4
**/
GParamSpec *
gimp_param_spec_parasite (const gchar *name,
@@ -236,8 +234,6 @@ gimp_parasite_print (GimpParasite *parasite)
* which case you may want to set @size as strlen(@data) + 1) or not.
*
* Returns: (transfer full): a new #GimpParasite.
- *
- * Since: 1.1.23
*/
GimpParasite *
gimp_parasite_new (const gchar *name,
@@ -268,8 +264,6 @@ gimp_parasite_new (const gchar *name,
* @parasite: a #GimpParasite
*
* Free @parasite's dynamically allocated memory.
- *
- * Since: 1.1.23
*/
void
gimp_parasite_free (GimpParasite *parasite)
@@ -294,8 +288,6 @@ gimp_parasite_free (GimpParasite *parasite)
* Compare parasite's names.
*
* Returns: %TRUE if @parasite is named @name, %FALSE otherwise.
- *
- * Since: 1.1.23
*/
gboolean
gimp_parasite_is_type (const GimpParasite *parasite,
@@ -314,8 +306,6 @@ gimp_parasite_is_type (const GimpParasite *parasite,
* Create a new parasite with all the same values.
*
* Returns: (transfer full): a newly allocated #GimpParasite with same contents.
- *
- * Since: 1.1.23
*/
GimpParasite *
gimp_parasite_copy (const GimpParasite *parasite)
@@ -335,8 +325,6 @@ gimp_parasite_copy (const GimpParasite *parasite)
* Compare parasite's contents.
*
* Returns: %TRUE if @a and @b have same contents, %FALSE otherwise.
- *
- * Since: 1.1.23
*/
gboolean
gimp_parasite_compare (const GimpParasite *a,
@@ -362,8 +350,6 @@ gimp_parasite_compare (const GimpParasite *a,
* @parasite: a #GimpParasite
*
* Returns: @parasite flags.
- *
- * Since: 1.1.23
*/
gulong
gimp_parasite_flags (const GimpParasite *parasite)
@@ -379,8 +365,6 @@ gimp_parasite_flags (const GimpParasite *parasite)
* @parasite: a #GimpParasite
*
* Returns: %TRUE if @parasite is persistent, %FALSE otherwise.
- *
- * Since: 1.1.23
*/
gboolean
gimp_parasite_is_persistent (const GimpParasite *parasite)
@@ -396,8 +380,6 @@ gimp_parasite_is_persistent (const GimpParasite *parasite)
* @parasite: a #GimpParasite
*
* Returns: %TRUE if @parasite is undoable, %FALSE otherwise.
- *
- * Since: 1.1.23
*/
gboolean
gimp_parasite_is_undoable (const GimpParasite *parasite)
@@ -414,8 +396,6 @@ gimp_parasite_is_undoable (const GimpParasite *parasite)
* @flag: a parasite flag
*
* Returns: %TRUE if @parasite has @flag set, %FALSE otherwise.
- *
- * Since: 1.1.23
*/
gboolean
gimp_parasite_has_flag (const GimpParasite *parasite,
@@ -432,8 +412,6 @@ gimp_parasite_has_flag (const GimpParasite *parasite,
* @parasite: a #GimpParasite
*
* Returns: @parasite's name.
- *
- * Since: 1.1.23
*/
const gchar *
gimp_parasite_name (const GimpParasite *parasite)
@@ -454,8 +432,6 @@ gimp_parasite_name (const GimpParasite *parasite)
* data.
*
* Returns: @parasite's data.
- *
- * Since: 1.1.23
*/
gconstpointer
gimp_parasite_data (const GimpParasite *parasite)
@@ -471,8 +447,6 @@ gimp_parasite_data (const GimpParasite *parasite)
* @parasite: a #GimpParasite
*
* Returns: @parasite's data size.
- *
- * Since: 1.1.23
*/
glong
gimp_parasite_data_size (const GimpParasite *parasite)
diff --git a/libgimpbase/gimpparasite.h b/libgimpbase/gimpparasite.h
index 3c17bf78bb..0d550ba3ec 100644
--- a/libgimpbase/gimpparasite.h
+++ b/libgimpbase/gimpparasite.h
@@ -48,6 +48,8 @@ GType gimp_parasite_get_type (void) G_GNUC_CONST;
#define GIMP_TYPE_PARAM_PARASITE (gimp_param_parasite_get_type ())
#define GIMP_IS_PARAM_SPEC_PARASITE(pspec) (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), GIMP_TYPE_PARAM_PARASITE))
+typedef struct _GimpParamSpecParasite GimpParamSpecParasite;
+
GType gimp_param_parasite_get_type (void) G_GNUC_CONST;
GParamSpec * gimp_param_spec_parasite (const gchar *name,
diff --git a/libgimpbase/gimputils.c b/libgimpbase/gimputils.c
index a6f141e2f3..514f68ee1d 100644
--- a/libgimpbase/gimputils.c
+++ b/libgimpbase/gimputils.c
@@ -1195,7 +1195,7 @@ gimp_stack_trace_available (gboolean optimal)
/**
* gimp_stack_trace_print:
* @prog_name: the program to attach to.
- * @stream: a #FILE * stream.
+ * @stream: a FILE* stream.
* @trace: location to store a newly allocated string of the trace.
*
* Attempts to generate a stack trace at current code position in
diff --git a/libgimpcolor/gimprgb.c b/libgimpcolor/gimprgb.c
index 83749078b3..64c4767a1a 100644
--- a/libgimpcolor/gimprgb.c
+++ b/libgimpcolor/gimprgb.c
@@ -576,8 +576,6 @@ gimp_rgba_distance (const GimpRGB *rgba1,
#define GIMP_PARAM_SPEC_RGB(pspec) (G_TYPE_CHECK_INSTANCE_CAST ((pspec), GIMP_TYPE_PARAM_RGB,
GimpParamSpecRGB))
-typedef struct _GimpParamSpecRGB GimpParamSpecRGB;
-
struct _GimpParamSpecRGB
{
GParamSpecBoxed parent_instance;
diff --git a/libgimpcolor/gimprgb.h b/libgimpcolor/gimprgb.h
index 0bb0791bad..0ccce00f4c 100644
--- a/libgimpcolor/gimprgb.h
+++ b/libgimpcolor/gimprgb.h
@@ -50,6 +50,7 @@ void gimp_value_set_rgb (GValue *value,
#define GIMP_TYPE_PARAM_RGB (gimp_param_rgb_get_type ())
#define GIMP_IS_PARAM_SPEC_RGB(pspec) (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), GIMP_TYPE_PARAM_RGB))
+typedef struct _GimpParamSpecRGB GimpParamSpecRGB;
GType gimp_param_rgb_get_type (void) G_GNUC_CONST;
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/libgimpbase/gimpparamspecs.c b/libgimpbase/gimpparamspecs.c
index bbd5e11507..b55b2297b4 100644
--- a/libgimpbase/gimpparamspecs.c
+++ b/libgimpbase/gimpparamspecs.c
@@ -472,7 +472,7 @@ gimp_param_string_validate (GParamSpec *pspec,
* @flags: Flags for the property specified.
*
* Creates a new #GimpParamSpecString specifying a
- * #GIMP_TYPE_STRING property.
+ * #G_TYPE_STRING property.
*
* If @allow_non_utf8 is %FALSE, non-valid UTF-8 strings will be
* replaced by question marks.
@@ -1647,7 +1647,7 @@ gimp_rgb_array_get_type (void)
static GType type = 0;
if (! type)
- type = g_boxed_type_register_static ("GimpRgbArray",
+ type = g_boxed_type_register_static ("GimpRGBArray",
(GBoxedCopyFunc) gimp_array_copy,
(GBoxedFreeFunc) gimp_array_free);
@@ -1705,12 +1705,12 @@ gimp_param_rgb_array_init (GParamSpec *pspec)
* @blurb: Description of the property specified.
* @flags: Flags for the property specified.
*
* Creates a new #GimpParamSpecRgbArray specifying a
* #GIMP_TYPE_RGB_ARRAY property.
*
* See g_param_spec_internal() for details on property names.
*
* Returns: (transfer full): The newly created #GimpParamSpecRgbArray.
*
* Since: 3.0
**/
@@ -1705,12 +1705,12 @@ gimp_param_rgb_array_init (GParamSpec *pspec)
* @flags: Flags for the property specified.
*
- * Creates a new #GimpParamSpecRgbArray specifying a
+ * Creates a new #GimpParamSpecRGBArray specifying a
* #GIMP_TYPE_RGB_ARRAY property.
*
@@ -1705,12 +1705,12 @@ gimp_param_rgb_array_init (GParamSpec *pspec)
* See g_param_spec_internal() for details on property names.
*
- * Returns: (transfer full): The newly created #GimpParamSpecRgbArray.
+ * Returns: (transfer full): The newly created #GimpParamSpecRGBArray.
*
* Since: 3.0